This is the second python project after clioetxt.
This module is created to handle csv file data by importing data for removing duplicate data, removing unwanted header and footer, append data, merging multiple files and export list data to csv or txt file by specifying the delimiter.

I will work on adding more useful function later in future.

- Cheny Lioe -

Read the documentation after you install the package:
$ python -m pydoc -p 8000
Server ready at http://localhost:8000/
Server commands: [b]rowser, [q]uit
server> b
Then browse to clioecsv(package) to read documentation

Package contents:  clioecsv 
import_csv_as_list, distinct_by_column, distinct_by_columns, distinct_list_bycolumns, sort_list, sorted_list, remove_blank_top, remove_blank_bottom, export_to_csv, append_file, merge_files, transpose, append_column, append_columns

